/////////////////////////////////////////////////////////////////////////////////////////////////
//
// 	ABS-9000 DeviceServer WebAPI jquery アクセス用ライブラリ
//	
//  2012/4/1	ver1.00
//
//  copyright(c) all rights reserved 2012 All Blue System
//


// 	Webサーバーから、別のPC で実行中の DeviceServerにアクセスする場合の
//	URLホスト名とポート番号部分を設定する
//
//  DeviceServer 自身の HTTP サーバー機能を使用している場合には "" にする
//
//var server_host_url = "http://your_DeviceServer_public_url:80";

var server_host_url = "";


// DeviceServer セッション認証用トークン文字列
//
// ユーザーをログインフォームで認証する場合にはこの変数の初期値は "" にしておく。
//
// 認証を省略する場合には、既に DeviceServer に作成済みのセッショントークン文字列を指定できる。
// この場合には、DeviceServerの SERVER_START.lua ファイル中に、下記の用にセッショントークンを
// 作成するための記述を追加する
//
//  SERVER_START.lua ファイル
// 
//　--------------------------------------------------------
//　-- 認証を省略してアクセスするためのセッションを作成する
//　--------------------------------------------------------
//　if not create_session("1234",true) then error() end
//

var session_token = "";

/////////////////////////////////////////////////////////////////////////////////////////////////
//
// DeviceServer の LogService にログメッセージを出力する
//
/////////////////////////////////////////////////////////////////////////////////////////////////
function log(msg,module){
	var url = server_host_url + "/command/log?message=";
	url = url + encodeURIComponent(msg);
	if (module != undefined){
		url = url + "&module=" + encodeURIComponent(module);
	}
	$.get(url,"",function(data){},"text");
}

/////////////////////////////////////////////////////////////////////////////////////////////////
//
// DeviceServer のスクリプトを実行する。
// 第２パラメータにスクリプトパラメータを指定する
// callback パラメータを省略するとリターンパラメータを受け取らない
//
/////////////////////////////////////////////////////////////////////////////////////////////////
function script_exec(name,params,callback){
	if (callback == undefined){
		var callback = "default_callback";
    	var url = 	server_host_url + "/command/json/script" +
					"?session=" + encodeURIComponent(session_token) +
					"&resultrecords=0" +
					"&name=" + encodeURIComponent(name);
	} else {
    	var url = 	server_host_url + "/command/json/script" +
					"?session=" + encodeURIComponent(session_token) +
					"&name=" + encodeURIComponent(name);
	}

	for(key in params){
		url = url + "&" + encodeURIComponent(key) + "=" + encodeURIComponent(params[key]);
	}

	$.ajax({"url" : url,
			"dataType" : "jsonp",
			"jsonpCallback" : callback
	});
}

/////////////////////////////////////////////////////////////////////////////////////////////////
//
// DeviceServer にユーザー名とパスワードを指定してログインセッションを作成する
// 処理に成功した場合には、コールバック関数内でセッショントークン文字列を
// session_token グローバル変数に代入しておくこと。
//
/////////////////////////////////////////////////////////////////////////////////////////////////
function login(user,pass,callback){
   	var url = 	server_host_url + "/command/json/session_login" +
				"?user=" + encodeURIComponent(user) +
				"&pass=" + encodeURIComponent(pass);

	$.ajax({"url" : url,
			"dataType" : "jsonp",
			"jsonpCallback" : callback
	});
}

/////////////////////////////////////////////////////////////////////////////////////////////////
//
// DeviceServer からログアウトしてログインセッションを削除する
// 処理に成功した場合には、コールバック関数内で session_token グローバル変数をクリアしておくこと。
//
/////////////////////////////////////////////////////////////////////////////////////////////////
function logout(callback){
   	var url = 	server_host_url + "/command/json/session_logout" +
				"?session=" + encodeURIComponent(session_token);

	$.ajax({"url" : url,
			"dataType" : "jsonp",
			"jsonpCallback" : callback
	});
}

/////////////////////////////////////////////////////////////////////////////////////////////////
// script_exec() でコールバックを指定しない場合のデフォルトコールバック関数
/////////////////////////////////////////////////////////////////////////////////////////////////
function default_callback(data){
	if (data.Result != "Success"){
		log("*ERROR* script error!");
		return;
	} 
}

/////////////////////////////////////////////////////////////////////////////////////////////////
// login() のコールバック関数に設定されるイベントデータの内容をログに出力する関数
// ユーザーの作成するコールバック関数中からコールすることができる
/////////////////////////////////////////////////////////////////////////////////////////////////
function dump_login_result(data){
	log("Result[Result] = " + data.Result);
	log("Result[ErrorText] = " + data.ErrorText);
	log("Result[SessionToken] = " + data.SessionToken);
	log("Result[PrevLoginTimeStamp] = " + data.PrevLoginTimeStamp);
	for(v in data.Account) {
		log("Account[" + v + "] = " + data.Account[v]);
	};
	for(v in data.Permission) {
		log("Permission[" + v + "] = " + data.Permission[v]);
	};
}

/////////////////////////////////////////////////////////////////////////////////////////////////
// 予め用意されている script_exec() で指定可能なコールバック関数
// スクリプト実行コマンド(/command/json/script)で返されるデータをログに出力する
/////////////////////////////////////////////////////////////////////////////////////////////////
function dump_script_result(data){
	log("Result[Result] = " + data.Result);
	log("Result[ErrorText] = " + data.ErrorText);
	log("Result[TaskID] = " + data.TaskID);
	for(v in data.ResultParams) {
		log("ResultParams[" + v + "] = " + data.ResultParams[v]);
	};
}
